@@ -4,13 +4,24 @@ import asyncio
 import requests
 import aiohttp
 
-from python3_anticaptcha import create_task_url, app_key, get_sync_result, get_async_result, \
-                                ParamError, ReadError
+from python3_anticaptcha import (
+    create_task_url,
+    app_key,
+    get_sync_result,
+    get_async_result,
+    ParamError,
+    ReadError,
+)
 
 
 class NoCaptchaTask:
-
-    def __init__(self, anticaptcha_key: str, sleep_time: int = 10, callbackUrl: str = None, **kwargs):
+    def __init__(
+        self,
+        anticaptcha_key: str,
+        sleep_time: int = 10,
+        callbackUrl: str = None,
+        **kwargs,
+    ):
         """
         Модуль отвечает за решение NoCaptcha.
         :param anticaptcha_key: ключ от АнтиКапчи
@@ -20,28 +31,28 @@ class NoCaptchaTask:
         """
 
         if sleep_time < 10:
-            raise ValueError(f'Параметр `sleep_time` должен быть не менее 10. Вы передали - {sleep_time}')
+            raise ValueError(
+                f"Параметр `sleep_time` должен быть не менее 10. Вы передали - {sleep_time}"
+            )
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
-        self.task_payload = {"clientKey": anticaptcha_key,
-                             "task":
-                                 {
-                                     "type": "NoCaptchaTask",
-                                 },
-                             "softId": app_key
-                             }
+        self.task_payload = {
+            "clientKey": anticaptcha_key,
+            "task": {"type": "NoCaptchaTask"},
+            "softId": app_key,
+        }
 
         # задаём callbackUrl если передан
         if callbackUrl:
-            self.task_payload.update({'callbackUrl': callbackUrl})
+            self.task_payload.update({"callbackUrl": callbackUrl})
 
         # пайлоад для получения ответа сервиса
         self.result_payload = {"clientKey": anticaptcha_key}
         # заполнить пайлоад остальными аргументами
         if kwargs:
             for key in kwargs:
-                self.task_payload['task'].update({key: kwargs[key]})
+                self.task_payload["task"].update({key: kwargs[key]})
 
     def __enter__(self):
         return self
@@ -59,30 +70,38 @@ class NoCaptchaTask:
         :param: websiteKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
         return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
         """
-        self.task_payload['task'].update({"websiteURL": websiteURL,
-                                          "websiteKey": websiteKey})
+        self.task_payload["task"].update(
+            {"websiteURL": websiteURL, "websiteKey": websiteKey}
+        )
         # отправляем реквест, в ответ получаем JSON содержащий номер решаемой капчи
         captcha_id = requests.post(create_task_url, json=self.task_payload).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
-        if captcha_id['errorId'] == 0:
+        if captcha_id["errorId"] == 0:
             captcha_id = captcha_id["taskId"]
             self.result_payload.update({"taskId": captcha_id})
         else:
             return captcha_id
         # если передан параметр `callbackUrl` - не ждём решения капчи а возвращаем незаполненный ответ
-        if self.task_payload.get('callbackUrl'):
+        if self.task_payload.get("callbackUrl"):
             return self.result_payload
-            
+
         else:
             # Ждем решения капчи
             time.sleep(self.sleep_time)
-            return get_sync_result(result_payload = self.result_payload, sleep_time = self.sleep_time)
+            return get_sync_result(
+                result_payload=self.result_payload, sleep_time=self.sleep_time
+            )
 
 
 class aioNoCaptchaTask:
-
-    def __init__(self, anticaptcha_key: str, sleep_time: str = 10, callbackUrl: str = None, **kwargs):
+    def __init__(
+        self,
+        anticaptcha_key: str,
+        sleep_time: str = 10,
+        callbackUrl: str = None,
+        **kwargs,
+    ):
         """
         Модуль отвечает за решение NoCaptcha.
         :param anticaptcha_key: ключ от АнтиКапчи
@@ -92,29 +111,29 @@ class aioNoCaptchaTask:
         """
 
         if sleep_time < 10:
-            raise ValueError(f'Параметр `sleep_time` должен быть не менее 10. Вы передали - {sleep_time}')
+            raise ValueError(
+                f"Параметр `sleep_time` должен быть не менее 10. Вы передали - {sleep_time}"
+            )
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
-        self.task_payload = {"clientKey": anticaptcha_key,
-                             "task":
-                                 {
-                                     "type": "NoCaptchaTask",
-                                 },
-                             "softId": app_key
-                             }
+        self.task_payload = {
+            "clientKey": anticaptcha_key,
+            "task": {"type": "NoCaptchaTask"},
+            "softId": app_key,
+        }
 
         # задаём callbackUrl если передан
         if callbackUrl:
-            self.task_payload.update({'callbackUrl': callbackUrl})
+            self.task_payload.update({"callbackUrl": callbackUrl})
 
         # пайлоад для получения ответа сервиса
         self.result_payload = {"clientKey": anticaptcha_key}
         # заполнить пайлоад остальными аргументами
         if kwargs:
             for key in kwargs:
-                self.task_payload['task'].update({key: kwargs[key]})
-	
+                self.task_payload["task"].update({key: kwargs[key]})
+
     def __enter__(self):
         return self
 
@@ -131,8 +150,9 @@ class aioNoCaptchaTask:
         :param: websiteKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
         return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
         """
-        self.task_payload["task"].update({"websiteURL": websiteURL,
-                                          "websiteKey": websiteKey})
+        self.task_payload["task"].update(
+            {"websiteURL": websiteURL, "websiteKey": websiteKey}
+        )
         # отправляем реквест, в ответ получаем JSON содержащий номер решаемой капчи
         async with aiohttp.ClientSession() as session:
             async with session.post(create_task_url, json=self.task_payload) as resp:
@@ -146,10 +166,12 @@ class aioNoCaptchaTask:
             return captcha_id
 
         # если передан параметр `callbackUrl` - не ждём решения капчи а возвращаем незаполненный ответ
-        if self.task_payload.get('callbackUrl'):
+        if self.task_payload.get("callbackUrl"):
             return self.result_payload
-            
+
         else:
             # Ждем решения капчи
             await asyncio.sleep(self.sleep_time)
-            return await get_async_result(result_payload = self.result_payload, sleep_time = self.sleep_time)
+            return await get_async_result(
+                result_payload=self.result_payload, sleep_time=self.sleep_time
+            )
